@@ -2,10 +2,15 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .account import *
+
+from . import account
 
 
 def register():
     Pool.register(
-        AccountTemplate,
+        account.BEVATCustomer,
+        account.BEVATCustomerContext,
         module='account_be', type_='model')
+    Pool.register(
+        account.CreateChart,
+        module='account_be', type_='wizard')
