@@ -2,37 +2,34 @@
 # this repository contains the full copyright notices and license terms.
 from sql import Literal
 from sql.aggregate import Max, Min, Sum
-from sql.operators import Concat
-from sql.functions import Position
 
 from trytond.model import ModelSQL, ModelView, fields
+from trytond.modules.account.exceptions import FiscalYearNotFoundError
+from trytond.modules.currency.fields import Monetary
 from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 
 
-class AccountTemplate(metaclass=PoolMeta):
-    __name__ = 'account.account.template'
+class CreateChart(metaclass=PoolMeta):
+    __name__ = 'account.create_chart'
 
-    @classmethod
-    def __register__(cls, module_name):
+    def default_properties(self, fields):
         pool = Pool()
         ModelData = pool.get('ir.model.data')
-        cursor = Transaction().connection.cursor()
-        model_data = ModelData.__table__()
-
-        # Migration from 3.4: translation of the account chart
-        cursor.execute(*model_data.select(model_data.id,
-                where=((model_data.fs_id == 'be')
-                    & (model_data.module == 'account_be'))))
-        if cursor.fetchone():
-            cursor.execute(*model_data.update(
-                    columns=[model_data.fs_id],
-                    values=[Concat(model_data.fs_id, '_fr')],
-                    where=((Position('_fr', model_data.fs_id) == 0)
-                        & (model_data.module == 'account_be'))))
-
-        super(AccountTemplate, cls).__register__(module_name)
+        defaults = super().default_properties(fields)
+        for lang in ['fr', 'nl']:
+            try:
+                template_id = ModelData.get_id('account_be.root_' + lang)
+            except KeyError:
+                continue
+            if self.account.account_template.id == template_id:
+                defaults['account_receivable'] = self.get_account(
+                    'account_be.400_' + lang)
+                defaults['account_payable'] = self.get_account(
+                    'account_be.440_' + lang)
+                break
+        return defaults
 
 
 class BEVATCustomer(ModelSQL, ModelView):
@@ -43,18 +40,9 @@ class BEVATCustomer(ModelSQL, ModelView):
         'party.identifier', "Company Tax Identifier")
     party_tax_identifier = fields.Many2One(
         'party.identifier', "Party Tax Identifier")
-    turnover = fields.Numeric(
-        "Turnover", digits=(16, Eval('currency_digits', 2)),
-        depends=['currency_digits'])
-    vat = fields.Numeric(
-        "VAT", digits=(16, Eval('currency_digits', 2)),
-        depends=['currency_digits'])
+    turnover = Monetary("Turnover", currency='currency', digits='currency')
+    vat = Monetary("VAT", currency='currency', digits='currency')
     currency = fields.Many2One('currency.currency', "Currency")
-    currency_digits = fields.Function(
-        fields.Integer("Currency Digits"), 'get_currency_digits')
-
-    def get_currency_digits(self, name):
-        return self.currency.digits
 
     @classmethod
     def tax_groups(cls):
@@ -138,8 +126,7 @@ class BEVATCustomerContext(ModelView):
         'account.fiscalyear', "Fiscal Year", required=True,
         domain=[
             ('company', '=', Eval('company')),
-            ],
-        depends=['company'])
+            ])
 
     @classmethod
     def default_company(cls):
@@ -150,6 +137,11 @@ class BEVATCustomerContext(ModelView):
         pool = Pool()
         FiscalYear = pool.get('account.fiscalyear')
         context = Transaction().context
-        return context.get(
-            'fiscalyear',
-            FiscalYear.find(context.get('company'), exception=False))
+        if 'fiscalyear' not in context:
+            try:
+                fiscalyear = FiscalYear.find(
+                    cls.default_company(), test_state=False)
+            except FiscalYearNotFoundError:
+                return None
+            return fiscalyear.id
+        return context['fiscalyear']
